==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/so-SO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Agabka waa la hubiyay',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Hantida la hubiyay',
    'Asset_Checkout_Notification' => 'Hantida la hubiyay',
    'Confirm_Accessory_Checkin' => 'Xaqiijinta hubinta dheeraadka ah',
    'Confirm_Asset_Checkin' => 'Xaqiijinta hubinta hantida',
    'Confirm_accessory_delivery' => 'Xaqiijinta gaarsiinta agabka',
    'Confirm_asset_delivery' => 'Xaqiijinta keenista hantida',
    'Confirm_consumable_delivery' => 'Xaqiijinta keenista la isticmaali karo',
    'Confirm_license_delivery' => 'Xaqiijinta bixinta shatiga',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Maalmo',
    'Expected_Checkin_Date' => 'Hantida lagugu hubiyay waa in lagugu soo celiyaa :date',
    'Expected_Checkin_Notification' => 'Xusuusin: :name wakhtiga kama dambaysta ah ee hubinta ayaa soo dhow',
    'Expected_Checkin_Report' => 'Warbixinta hubinta hantida la filayo',
    'Expiring_Assets_Report' => 'Warbixinta Hantida Dhacaysa',
    'Expiring_Licenses_Report' => 'Warbixinta Shatiyada Dhacaya',
    'Item_Request_Canceled' => 'Codsiga shayga waa la joojiyay',
    'Item_Requested' => 'Shayga la codsaday',
    'License_Checkin_Notification' => 'Shatiga waa la hubiyay',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Warbixinta Alaabada Hoose',
    'a_user_canceled' => 'Isticmaaluhu waxa uu joojiyay shay codsi ah oo ku jiray mareegaha',
    'a_user_requested' => 'Isticmaaluhu wuxuu ka codsaday shay shabakada',
    'acceptance_asset_accepted' => 'Isticmaaluhu waa aqbalay shay',
    'acceptance_asset_declined' => 'Isticmaaluhu waa diiday shay',
    'accessory_name' => 'Magaca Agabka:',
    'additional_notes' => 'Qoraalo Dheeraad ah:',
    'admin_has_created' => 'Maamule ayaa akoon kaaga sameeyay :web mareegaha',
    'asset' => 'Hantida:',
    'asset_name' => 'Magaca Hantida:',
    'asset_requested' => 'Hantida la codsaday',
    'asset_tag' => 'Hantida Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Loo xilsaaray',
    'best_regards' => 'Salaan wanagsan',
    'canceled' => 'La joojiyay:',
    'checkin_date' => 'Taariikhda la soo galayo:',
    'checkout_date' => 'Taariikhda Bixinta:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Laga soo hubiyay',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Fadlan dhagsii xiriirka hoose si aad u xaqiijiso inaad heshay agabka.',
    'click_on_the_link_asset' => 'Fadlan ku dhufo xiriirka hoose si aad u xaqiijiso inaad heshay hantida.',
    'click_to_confirm' => 'Fadlan dhagsii xidhiidhka soo socda si aad u xaqiijiso :web akoonkaaga:',
    'current_QTY' => 'QTY-da hadda',
    'days' => 'Maalmo',
    'expecting_checkin_date' => 'Taariikhda la filayo:',
    'expires' => 'Dhacaya',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Waan akhriyay oo waan aqbalay shuruudaha isticmaalka, waxaana helay shaygan.',
    'inventory_report' => 'Warbixinta Alaabada',
    'item' => 'Shayga:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Fadlan dhagsii xidhiidhka soo socda si aad u cusboonaysiiso :web eraygaaga sirta ah:',
    'login' => 'Soo gal:',
    'login_first_admin' => 'Soo gal rakibaaddaada cusub ee Snipe-IT adoo isticmaalaya aqoonsiga hoose:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Magaca',
    'new_item_checked' => 'Shay cusub ayaa lagu hubiyay magacaaga hoostiisa.',
    'notes' => 'Xusuusin',
    'password' => 'Furaha sirta ah:',
    'password_reset' => 'Dib u habaynta erayga sirta ah',
    'read_the_terms' => 'Fadlan hoos ka akhri shuruudaha isticmaalka',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'La codsaday:',
    'reset_link' => 'Xidhiidhka Dib-u-dejinta Furahaaga',
    'reset_password' => 'Riix halkan si aad dib ugu dejiso eraygaaga sirta ah:',
    'rights_reserved' => 'Dhammaan xuquuqaha way xifdiyeen',
    'serial' => 'Taxane',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Alaab-qeybiye',
    'tag' => 'Tag',
    'test_email' => 'Tijaabi iimaylka Snipe-IT',
    'test_mail_text' => 'Kani waa imtixaan ka yimid Nidaamka Maareynta Hantida Snipe-IT. Haddii aad tan heshay, boostada ayaa shaqaynaysa :)',
    'the_following_item' => 'Shayga soo socda ayaa la hubiyay: ',
    'to_reset' => 'Si dib loogu dejiyo :web eraygaaga sirta ah, buuxi foomkan:',
    'type' => 'Nooca',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Isticmaale',
    'username' => 'Magaca isticmaale',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Soo dhawoow :name',
    'welcome_to' => 'Ku soo dhawoow :web!',
    'your_assets' => 'Arag Hantidaada',
    'your_credentials' => 'Aqoonsigaaga Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/so-SO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Agabka waa la hubiyay',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Hantida la hubiyay',
    'Asset_Checkout_Notification' => 'Hantida la hubiyay',
    'Confirm_Accessory_Checkin' => 'Xaqiijinta hubinta dheeraadka ah',
    'Confirm_Asset_Checkin' => 'Xaqiijinta hubinta hantida',
    'Confirm_accessory_delivery' => 'Xaqiijinta gaarsiinta agabka',
    'Confirm_asset_delivery' => 'Xaqiijinta keenista hantida',
    'Confirm_consumable_delivery' => 'Xaqiijinta keenista la isticmaali karo',
    'Confirm_license_delivery' => 'Xaqiijinta bixinta shatiga',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Maalmo',
    'Expected_Checkin_Date' => 'Hantida lagugu hubiyay waa in lagugu soo celiyaa :date',
    'Expected_Checkin_Notification' => 'Xusuusin: :name wakhtiga kama dambaysta ah ee hubinta ayaa soo dhow',
    'Expected_Checkin_Report' => 'Warbixinta hubinta hantida la filayo',
    'Expiring_Assets_Report' => 'Warbixinta Hantida Dhacaysa',
    'Expiring_Licenses_Report' => 'Warbixinta Shatiyada Dhacaya',
    'Item_Request_Canceled' => 'Codsiga shayga waa la joojiyay',
    'Item_Requested' => 'Shayga la codsaday',
    'License_Checkin_Notification' => 'Shatiga waa la hubiyay',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Warbixinta Alaabada Hoose',
    'a_user_canceled' => 'Isticmaaluhu waxa uu joojiyay shay codsi ah oo ku jiray mareegaha',
    'a_user_requested' => 'Isticmaaluhu wuxuu ka codsaday shay shabakada',
    'acceptance_asset_accepted' => 'Isticmaaluhu waa aqbalay shay',
    'acceptance_asset_declined' => 'Isticmaaluhu waa diiday shay',
    'accessory_name' => 'Magaca dheeriga ah',
    'additional_notes' => 'Qoraalo Dheeraad ah',
    'admin_has_created' => 'Maamule ayaa akoon kaaga sameeyay :web mareegaha',
    'asset' => 'Hantida',
    'asset_name' => 'Magaca Hantida',
    'asset_requested' => 'Hantida la codsaday',
    'asset_tag' => 'Hantida Tag',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Loo xilsaaray',
    'best_regards' => 'Salaan wanagsan',
    'canceled' => 'La joojiyay',
    'checkin_date' => 'Taariikhda la soo galayo',
    'checkout_date' => 'Taariikhda Bixinta',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Laga soo hubiyay',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Fadlan dhagsii xiriirka hoose si aad u xaqiijiso inaad heshay agabka.',
    'click_on_the_link_asset' => 'Fadlan ku dhufo xiriirka hoose si aad u xaqiijiso inaad heshay hantida.',
    'click_to_confirm' => 'Fadlan dhagsii xidhiidhka soo socda si aad u xaqiijiso :web akoonkaaga:',
    'current_QTY' => 'QTY-da hadda',
    'days' => 'Maalmo',
    'expecting_checkin_date' => 'Taariikhda la filayo',
    'expires' => 'Dhacaya',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Waan akhriyay oo waan aqbalay shuruudaha isticmaalka, waxaana helay shaygan.',
    'inventory_report' => 'Warbixinta Alaabada',
    'item' => 'Shayga',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Fadlan dhagsii xidhiidhka soo socda si aad u cusboonaysiiso :web eraygaaga sirta ah:',
    'login' => 'Soo gal:',
    'login_first_admin' => 'Soo gal rakibaaddaada cusub ee Snipe-IT adoo isticmaalaya aqoonsiga hoose:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min QTY',
    'name' => 'Magaca',
    'new_item_checked' => 'Shay cusub ayaa lagu hubiyay magacaaga hoostiisa.',
    'notes' => 'Xusuusin',
    'password' => 'Password-ka',
    'password_reset' => 'Dib u habaynta erayga sirta ah',
    'read_the_terms' => 'Fadlan hoos ka akhri shuruudaha isticmaalka',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'La codsaday',
    'reset_link' => 'Xidhiidhka Dib-u-dejinta Furahaaga',
    'reset_password' => 'Riix halkan si aad dib ugu dejiso eraygaaga sirta ah:',
    'rights_reserved' => 'Dhammaan xuquuqaha way xifdiyeen',
    'serial' => 'Taxane',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Alaab-qeybiye',
    'tag' => 'Tag',
    'test_email' => 'Tijaabi iimaylka Snipe-IT',
    'test_mail_text' => 'Kani waa imtixaan ka yimid Nidaamka Maareynta Hantida Snipe-IT. Haddii aad tan heshay, boostada ayaa shaqaynaysa :)',
    'the_following_item' => 'Shayga soo socda ayaa la hubiyay: ',
    'to_reset' => 'Si dib loogu dejiyo :web eraygaaga sirta ah, buuxi foomkan:',
    'type' => 'Nooca',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Isticmaale',
    'username' => 'Magaca isticmaale',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Soo dhawoow :name',
    'welcome_to' => 'Ku soo dhawoow :web!',
    'your_assets' => 'Arag Hantidaada',
    'your_credentials' => 'Aqoonsigaaga Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
